@@ -1,4 +1,5 @@
 use crate::cli_commands::{Cli, Commands};
+use base64::engine::general_purpose;
 use clap::Parser;
 use log::info;
 use reqwest::{StatusCode, Url};
@@ -10,7 +11,7 @@ use url::ParseError;
 use crate::cli_commands::Mode;
 use crate::command::hoard_command::HoardCommand;
 use crate::command::trove::CommandTrove;
-use crate::config::HoardConfig;
+use crate::config::{compare_with_latest_version, HoardConfig};
 use crate::config::{load_or_build_config, save_hoard_config_file, save_parameter_token};
 use crate::filter::query_trove;
 use crate::gui::commands_gui;
@@ -20,7 +21,7 @@ use crate::gui::prompts::{
 };
 use crate::sync_models::TokenResponse;
 use crate::util::rem_first_and_last;
-use base64::encode;
+use base64::Engine as _;
 
 #[derive(Default, Debug)]
 pub struct Hoard {
@@ -44,7 +45,12 @@ impl Hoard {
         self
     }
 
-    pub fn start(&mut self) -> (String, bool) {
+    pub async fn start(&mut self) -> (String, bool) {
+        if !compare_with_latest_version().await.0 {
+            println!(
+                "A newer Version ({}) is available at https://github.com/Hyde46/hoard \nPlease update.", compare_with_latest_version().await.1
+            );
+        }
         let mut autocomplete_command = String::new();
         let cli = Cli::parse();
 
@@ -413,7 +419,7 @@ impl Hoard {
         });
     }
 
-    fn regsiter_user(&mut self) {
+    fn register_user(&mut self) {
         println!("Registering account..");
         let user_email = prompt_input("Email: ", false, None);
         let user_pw: String = prompt_password_repeat("Password: ");
@@ -456,7 +462,7 @@ impl Hoard {
             let response_text = body.text().unwrap();
             let token = serde_yaml::from_str::<TokenResponse>(&response_text).unwrap();
             let mut config = self.config.clone().unwrap();
-            let b64_token = encode(token.token);
+            let b64_token = general_purpose::STANDARD.encode(token.token);
             config.api_token = Some(b64_token);
             save_hoard_config_file(&config, &config.clone().config_home_path.unwrap()).unwrap();
             println!("Success!");
@@ -520,7 +526,7 @@ impl Hoard {
         // Check if user is logged in
         // Else inform the user to run `hoard sync login` first and break
         match command {
-            Mode::Register => self.regsiter_user(),
+            Mode::Register => self.register_user(),
             Mode::Login => {
                 if self.is_logged_in() {
                     println!("You are already logged in.");
