@@ -17,8 +17,13 @@ mod sync_models;
 mod util;
 use hoard::Hoard;
 
-fn main() {
-    let (command, is_autocomplete) = Hoard::default().with_config(None).load_trove().start();
+#[tokio::main]
+async fn main() {
+    let (command, is_autocomplete) = Hoard::default()
+        .with_config(None)
+        .load_trove()
+        .start()
+        .await;
     if is_autocomplete {
         eprintln!("{}", command.trim());
     } else {
